# Directory to crx

![GitHub all releases](https://img.shields.io/github/downloads/chernyshev-aleksey/dir_fo_crx/total) ![GitHub](https://img.shields.io/github/license/chernyshev-aleksey/dir_fo_crx)

## Installation
```
pip install dir_to_crx
```